! ESA (C) 2000-2018 
!
! This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
!
!    SAS is free software: you can redistribute it and/or modify
!    it under the terms of the GNU General Public License as published by
!    the Free Software Foundation, either version 3 of the License, or
!    (at your option) any later version.
!
!    SAS is distributed in the hope that it will be useful,
!    but WITHOUT ANY WARRANTY; without even the implied warranty of
!    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!    GNU General Public License for more details.
!
!    You should have received a copy of the GNU General Public License
!    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
!+
! Module: rudiframetime_mod
!
! Authors:  Jon Rainger - MSSL
!          
! Description: Calculates CCD frametime and deadtime from window data.
! 
! Comments: 
! 
! $Id: module.f90,v 1.6 1998/05/27 13:45:39 gvacanti Exp $
!- 
! Changes
!       06.12.2001 (CB) Added boolean parameter binbpe (defaults to FALSE)
!       for call to getframetime
!***********************************************************************
module rudiframetime_mod

  use dal
  use param  
  use errorHandling
  use frameTime_mod

  implicit none 
  
  private 

  public rudiframetime

contains 
  
  !---------------------------------------------------------------------
  subroutine rudiframetime
  !---------------------------------------------------------------------

    character(len=255) :: wdxSet                      ! OM ODF Priority Window Data Auxiliary filename.
    type(DataSetT) :: wdxDataSetH                     ! Priority Window Data dataset handle.
    real(kind=double) :: frameTime                    ! OM CCD frame time.
    real(kind=double) :: deadFrac                     ! Dead time in units of CCD frame time.
    logical :: binBpe
! Get Parameters

    wdxSet = stringParameter("wdxset")
    binBpe = booleanParameter("binbpe")


! Read in the OM ODF Priority Window Data Auxiliary file.

    wdxDataSetH = dataSet(wdxSet, read)

! Get the frame time from the OM ODF Priority Window Data Auxiliary file.

    call getFrameTime(wdxDataSetH, frametime, deadfrac, binBpe)

    call release(wdxDataSetH)

    write(*,*) "CCD READOUT TIME :",frametime,"ms"
    write(*,*) "DEAD TIME FRACTION:", deadfrac 
    
  end subroutine rudiframetime
  
end module rudiframetime_mod
